@@ -32,7 +32,7 @@ from petisco.domain.value_objects.string_value_object import (
 from petisco.domain.value_objects.user_id import UserId
 from petisco.domain.value_objects.correlation_id import CorrelationId
 from petisco.domain.value_objects.uuid import Uuid, InvalidUuidError
-from petisco.domain.value_objects.value_object import ValueObject
+from petisco.domain.value_objects.value_object import ValueObject, value_object_field
 from petisco.event.bus.domain.interface_event_bus import IEventBus
 from petisco.event.chaos.domain.interface_event_chaos import IEventChaos
 from petisco.event.handler.event_handler import event_handler
@@ -181,6 +181,7 @@ classes = [
     "Secret",
     "SignatureAlgorithm",
     "DateParser",
+    "value_object_field",
 ]
 
 
@@ -192,6 +193,8 @@ from petisco.persistence.persistence_models import PersistenceModels
 from petisco.persistence.sql.errors import (
     ClientNotFoundError,
     ClientAlreadyExistError,
+    UserNotFoundError,
+    UserAlreadyExistError,
     EntityAlreadyExistError,
     EntityNotFoundError,
     EntitiesNotFoundError,
@@ -205,6 +208,8 @@ persistence = [
     "IPersistenceConnector",
     "ClientNotFoundError",
     "ClientAlreadyExistError",
+    "UserNotFoundError",
+    "UserAlreadyExistError",
     "EntityAlreadyExistError",
     "EntityNotFoundError",
     "EntitiesNotFoundError",
@@ -258,16 +263,6 @@ except (RuntimeError, ImportError):
 
 # SqlAlchemy
 try:
-    from petisco.persistence.sqlalchemy.sqlalchemy_persistence import (
-        SqlAlchemyPersistence,
-    )
-    from petisco.persistence.sqlalchemy.sqlalchemy_persistence_config import (
-        SqlAlchemyPersistenceConfig,
-    )
-    from petisco.persistence.sqlalchemy.sqlalchemy_persistence_connector import (
-        SqlAlchemyPersistenceConnector,
-    )
-    from petisco.persistence.sqlalchemy.sqlalchemy_session_scope import session_scope
     from petisco.persistence.sqlalchemy.sqlalchemy_operational_database_error import (
         SqlAlchemyOperationalDatabaseError,
     )
@@ -276,18 +271,16 @@ try:
     from petisco.persistence.sql.mysql.mysql_connection import MySqlConnection
     from petisco.persistence.sql.mysql.mysql_database import MySqlDatabase
     from petisco.persistence.sql.sql_repository import SqlRepository
+    from petisco.persistence.sql.sql_executor import SqlExecutor
 
     sql = [
-        "SqlAlchemyPersistence",
-        "SqlAlchemyPersistenceConfig",
-        "SqlAlchemyPersistenceConnector",
-        "session_scope",
         "SqlAlchemyOperationalDatabaseError",
         "SqliteConnection",
         "SqliteDatabase",
         "MySqlConnection",
         "MySqlDatabase",
         "SqlRepository",
+        "SqlExecutor",
     ]
 except (RuntimeError, ImportError):
     sql = []
